import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:progamification/src/components/rank.dart';
import 'package:progamification/src/controllers/leader_board.dart';
import 'package:progamification/src/models/leader_board.dart';
import 'package:progamification/src/services/sas_token.service.dart';
import 'package:progamification/src/services/storage.service.dart';
import 'package:scroll_to_index/scroll_to_index.dart';

class LeaderBoardTable extends StatefulWidget {
  const LeaderBoardTable({super.key});

  @override
  State<LeaderBoardTable> createState() => _LeaderBoardTableState();
}

class _LeaderBoardTableState extends State<LeaderBoardTable> {
  final controller = AutoScrollController(
    axis: Axis.vertical,
  );
  LeaderBoardController leaderBoardController =
      Get.find<LeaderBoardController>();
  GamificationStorageService storageService =
      Get.find<GamificationStorageService>();
  LeaderBoardModel currentUser = LeaderBoardModel();
  SasTokenService sasTokenService = Get.find<SasTokenService>();
  String sasToken = "";
  String userId = '';
  final GlobalKey userKey = GlobalKey();

  @override
  initState() {
    super.initState();

    sasTokenService.getSasToken().then((value) {
      setState(() {
        sasToken = value.toString();
      });
    });
    storageService.getString('userId').then((value) => {
          setState(() {
            userId = value.toString();
          })
        });
  }

  @override
  Widget build(BuildContext context) {
    return LayoutBuilder(builder: (context, constraints) {
      return Scaffold(
          body: Stack(children: [
            Expanded(
                child: ListView.builder(
              controller: controller,
              shrinkWrap: true,
              itemCount: leaderBoardController.leaderBoardData.isNotEmpty
                  ? leaderBoardController.leaderBoardData.length
                  : 0,
              itemBuilder: (BuildContext context, int index) {
                if (index == 0) {
                  return const SizedBox(
                    height: 220.0,
                    width: double.infinity,
                    child: Rank(),
                  );
                }
                if (index >= 3) {
                  return AutoScrollTag(
                    key: ValueKey(index),
                    controller: controller,
                    index: index,
                    child: ListTile(
                      shape: RoundedRectangleBorder(
                        side: BorderSide(
                            color: leaderBoardController
                                        .leaderBoardData[index].userId
                                        .toString() ==
                                    userId
                                ? const Color(0xffFA5050)
                                : const Color.fromARGB(255, 238, 234, 234),
                            width: 1),
                      ),
                      tileColor: Colors.white,
                      selectedTileColor: const Color(0xffFDEAEA),
                      selectedColor: Colors.black,
                      contentPadding: const EdgeInsets.only(
                          left: 30, right: 20, top: 8.0, bottom: 8.0),
                      selected: leaderBoardController
                              .leaderBoardData[index].userId
                              .toString() ==
                          userId,
                      leading: Container(
                        decoration: BoxDecoration(
                          shape: BoxShape.circle,
                          color: leaderBoardController
                                      .leaderBoardData[index].userId
                                      .toString() ==
                                  userId
                              ? const Color(0xffFA5050)
                              : const Color(0xffEBEBEB),
                        ),
                        child: Padding(
                            padding: const EdgeInsets.all(7.75),
                            child: Text(
                              leaderBoardController.leaderBoardData[index].rank
                                  .toString(),
                              textAlign: TextAlign.start,
                              style: TextStyle(
                                  color: leaderBoardController
                                              .leaderBoardData[index].userId
                                              .toString() ==
                                          userId
                                      ? Colors.white
                                      : Colors.black,
                                  fontWeight: FontWeight.w600,
                                  fontSize: 16,
                                  fontFamily: GoogleFonts.poppins().fontFamily),
                            )),
                      ),
                      title: Row(children: [
                        Container(
                            margin: const EdgeInsets.only(right: 15.0),
                            width: 48.0,
                            height: 48.0,
                            decoration: const BoxDecoration(
                              shape: BoxShape.circle,
                            ),
                            child: ClipOval(
                                child: CachedNetworkImage(
                              key: UniqueKey(),
                              imageUrl: leaderBoardController
                                      .leaderBoardData[index].profileImageUrl
                                      .toString() +
                                  sasToken,
                              width: 50.0,
                              height: 50.0,
                              fit: BoxFit.fill,
                              placeholder: (context, url) => Image.asset(
                                "assets/icons/avatar.png",
                                package: "progamification",
                              ),
                              errorWidget: (context, url, error) => Image.asset(
                                "assets/icons/avatar.png",
                                package: "progamification",
                              ),
                            ))),
                        Expanded(
                            child: Text(
                          overflow: TextOverflow.ellipsis,
                          maxLines: 1,
                          textAlign: TextAlign.left,
                          leaderBoardController.leaderBoardData[index].userName
                              .toString(),
                          style: TextStyle(
                              fontWeight: FontWeight.w600,
                              fontSize: 16,
                              fontFamily:
                                  GoogleFonts.plusJakartaSans().fontFamily),
                        )),
                      ]),
                      trailing: Row(mainAxisSize: MainAxisSize.min, children: [
                        Image.asset(
                          "assets/icons/bolt.png",
                          package: "progamification",
                          width: 55,
                          height: 55,
                        ),
                        Text(
                          '${leaderBoardController.leaderBoardData[index].score}',
                          style: TextStyle(
                              fontWeight: FontWeight.w600,
                              fontSize: 15,
                              fontFamily:
                                  GoogleFonts.plusJakartaSans().fontFamily),
                        )
                      ]),
                    ),
                  );
                  ;
                } else {
                  return Container();
                }
              },
            ))
          ]),
          floatingActionButton: FloatingActionButton.extended(
            extendedPadding: const EdgeInsets.symmetric(horizontal: 0),
            backgroundColor: Colors.black,
            onPressed: () {
              int selectedIndex =
                  leaderBoardController.getCurrentUserIndex(userId)!;
              scrollToIndex(selectedIndex);
            },
            label: Row(children: [
              Container(
                  margin: const EdgeInsets.symmetric(horizontal: 10.0),
                  width: 33.0,
                  height: 33.0,
                  decoration: const BoxDecoration(
                    shape: BoxShape.circle,
                  ),
                  child: ClipOval(
                      child: CachedNetworkImage(
                    key: UniqueKey(),
                    imageUrl: currentUser.profileImageUrl + sasToken,
                    fit: BoxFit.fill,
                    placeholder: (context, url) => Image.asset(
                      "assets/icons/avatar.png",
                      package: "progamification",
                    ),
                    errorWidget: (context, url, error) => Image.asset(
                      "assets/icons/avatar.png",
                      package: "progamification",
                    ),
                  ))),
              const Text("You're here"),
              const Icon(Icons.arrow_drop_down)
            ]),
          ));
    });
  }

  Future<void> setCurrentUserLeaderBoardData() async {
    String userId = await storageService.getString('userId');
    LeaderBoardModel leaderboard =
        leaderBoardController.getLeaderBoardData(userId);
    setState(() {
      currentUser = leaderboard;
    });
  }

  void scrollToIndex(int index) {
    controller.scrollToIndex(index, preferPosition: AutoScrollPosition.middle);
  }
}
