// ignore_for_file: library_private_types_in_public_api, no_logic_in_create_state, use_key_in_widget_constructors, prefer_const_constructors_in_immutables

import 'package:progamification/src/components/achievements.dart';
import 'package:progamification/src/components/leaderboard_table.dart';
import 'package:progamification/src/controllers/leader_board.dart';
import 'package:get/get.dart';
import 'package:flutter/material.dart';
import 'package:progamification/src/services/leaderboard.service.dart';
import 'package:google_fonts/google_fonts.dart';

class LeaderBoard extends StatefulWidget {
  final String userId;
  final String applicationId;
  LeaderBoard(this.userId, this.applicationId);
  @override
  _LeaderBoardState createState() => _LeaderBoardState(userId, applicationId);
}

class _LeaderBoardState extends State<LeaderBoard> {
  late String userId;
  late String applicationId;
  bool isGamificationVisible = true;
  _LeaderBoardState(this.userId, this.applicationId);

  final LeaderBoardController leaderBoardController =
      Get.find<LeaderBoardController>();

  @override
  void initState() {
    super.initState();
    getData(userId, applicationId);
  }

  Future<void> getData(String userId, String applicationId) async {
    try {
      Get.put<LeaderBoardService>(LeaderBoardService(), permanent: true);
      LeaderBoardService leaderBoardService = Get.find();

      await leaderBoardService
          .getLeaderBoard(userId, applicationId)
          .then(leaderBoardController.setData);
    } catch (e) {
      setState(() {
        isGamificationVisible = false;
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return isGamificationVisible
        ? Container(
            padding: const EdgeInsets.only(left: 0, right: 0),
            decoration: BoxDecoration(
              borderRadius: BorderRadius.circular(10),
            ),
            child: Row(
              children: [
                InkWell(
                  onTap: (() async {
                    await leaderBoardController.getData(userId, applicationId);
                    await leaderBoardController.getRewards(
                        userId, applicationId);
                    showLeaderBoard();
                  }),
                  child: Container(
                    margin: const EdgeInsets.all(2),
                    child: const Icon(
                      Icons.sports_score_outlined,
                      color: Colors.black,
                    ),
                  ),
                ),
              ],
            ),
          )
        : Container();
  }

  showLeaderBoard() {
    showModalBottomSheet(
      backgroundColor: Colors.white,
      context: context,
      isScrollControlled: true,
      builder: (BuildContext context) => StatefulBuilder(
        builder: (BuildContext context, setState) => SingleChildScrollView(
          child: SizedBox(
            height: Get.height * 1,
            width: double.infinity,
            child: Column(
              children: [
                SizedBox(
                  height: MediaQuery.of(context).size.height,
                  child: NestedScrollView(
                    physics: const ScrollPhysics(parent: PageScrollPhysics()),
                    floatHeaderSlivers: true,
                    headerSliverBuilder:
                        (BuildContext context, bool innerBoxIsScrolled) {
                      return <Widget>[
                        // SliverAppBar(
                        //   leadingWidth: 100,
                        //   centerTitle: false,
                        //   titleSpacing: 0.0,
                        //   automaticallyImplyLeading: false,
                        //   expandedHeight:
                        //       MediaQuery.of(context).size.height * 0.1,
                        //   collapsedHeight:
                        //       MediaQuery.of(context).size.height * 0.1,
                        //   backgroundColor: Colors.white,
                        //   flexibleSpace: Container(
                        //     width: double.infinity,
                        //     alignment: Alignment.centerLeft,
                        //     margin: const EdgeInsets.only(top: 20, left: 20),
                        //     child: FloatingActionButton(
                        //       onPressed: (() => Navigator.pop(context)),
                        //       elevation: 0,
                        //       backgroundColor: Colors.grey[100],
                        //       child: const Icon(
                        //         Icons.close_sharp,
                        //         color: Colors.black,
                        //         size: 25,
                        //       ),
                        //     ),
                        //   ),
                        //   floating: true,
                        // ),
                      ];
                    },
                    body: DefaultTabController(
                      length: 2,
                      child: Scaffold(
                        // change
                        appBar: AppBar(
                          backgroundColor: Colors.white,
                          automaticallyImplyLeading: false,
                          toolbarHeight: kToolbarHeight,
                          title: null,
                          bottom: TabBar(
                            labelPadding:
                                const EdgeInsets.symmetric(vertical: 0),
                            indicatorSize: TabBarIndicatorSize.label,
                            labelColor: Colors.black87,
                            unselectedLabelColor: Colors.grey,
                            indicator: const UnderlineTabIndicator(
                              borderSide:
                                  BorderSide(width: 2, color: Colors.black87),
                              borderRadius: BorderRadius.only(
                                topLeft: Radius.circular(2),
                                topRight: Radius.circular(2),
                                bottomLeft: Radius.circular(2),
                                bottomRight: Radius.circular(2),
                              ),
                            ),
                            tabs: [
                              Tab(
                                  child: Padding(
                                padding: const EdgeInsets.only(
                                    left: 10.0, right: 10.0),
                                child: Text(
                                  "Achievements",
                                  style: TextStyle(
                                    letterSpacing: 1.0,
                                    fontWeight: FontWeight.w600,
                                    fontSize: 19.0,
                                    fontFamily: GoogleFonts.plusJakartaSans()
                                        .fontFamily,
                                  ),
                                ),
                              )),
                              Tab(
                                child: Padding(
                                    padding: const EdgeInsets.only(
                                        left: 10.0, right: 10.0),
                                    child: Text(
                                      "Leaderboard",
                                      style: TextStyle(
                                        letterSpacing: 1.0,
                                        fontWeight: FontWeight.w600,
                                        fontSize: 19.0,
                                        fontFamily:
                                            GoogleFonts.plusJakartaSans()
                                                .fontFamily,
                                      ),
                                    )),
                              ),
                            ],
                          ),
                        ),
                        body: const TabBarView(
                            children: [Achievements(), LeaderBoardTable()]),
                      ),
                    ),
                  ),
                ),
              ],
            ),
          ),
        ),
      ),
      //
    );
  }
}
